@@ -3,7 +3,8 @@
 # this is a translation of "Hello World III" from the GTK manual,
 # using gtkmodule
 
-from gtk import *
+from _gtk import *
+from _gtkbase import *
 from GTK import *
 
 def hello(*args):
@@ -15,6 +16,7 @@ def destroy(*args):
     gtk_main_quit()
 
 gtk_init()
+pygtk_init()
 
 window = gtk_window_new(WINDOW_TOPLEVEL)
 gtk_signal_connect(window, "destroy", destroy)
